@@ -572,7 +572,7 @@ class CreateDocumentRequest(AbstractModel):
         :type FlowId: str
         :param TemplateId: 用户上传的模板ID
         :type TemplateId: str
-        :param FileNames: 文件名列表,单个文件名最大长度200个字符
+        :param FileNames: 文件名列表，单个文件名最大长度200个字符，暂时仅支持单文件发起
         :type FileNames: list of str
         :param FormFields: 内容控件信息数组
         :type FormFields: list of FormField
@@ -660,7 +660,7 @@ class CreateFlowByFilesRequest(AbstractModel):
         :type FlowName: str
         :param Approvers: 签署参与者信息，最大限制50方
         :type Approvers: list of ApproverInfo
-        :param FileIds: 签署pdf文件的资源编号列表，通过UploadFiles接口获取
+        :param FileIds: 签署pdf文件的资源编号列表，通过UploadFiles接口获取，暂时仅支持单文件发起
         :type FileIds: list of str
         :param FlowType: 签署流程的类型(如销售合同/入职合同等)，最大长度200个字符
         :type FlowType: str
@@ -777,6 +777,57 @@ class CreateFlowByFilesResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class CreateFlowEvidenceReportRequest(AbstractModel):
+    """CreateFlowEvidenceReport请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Operator: 调用方用户信息，userId 必填
+        :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
+        :param FlowId: 签署流程编号
+        :type FlowId: str
+        """
+        self.Operator = None
+        self.FlowId = None
+
+
+    def _deserialize(self, params):
+        if params.get("Operator") is not None:
+            self.Operator = UserInfo()
+            self.Operator._deserialize(params.get("Operator"))
+        self.FlowId = params.get("FlowId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class CreateFlowEvidenceReportResponse(AbstractModel):
+    """CreateFlowEvidenceReport返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ReportUrl: 出证报告 URL（有效期5分钟）
+        :type ReportUrl: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.ReportUrl = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.ReportUrl = params.get("ReportUrl")
+        self.RequestId = params.get("RequestId")
+
+
 class CreateFlowRequest(AbstractModel):
     """CreateFlow请求参数结构体
 
